==> activity-center-api-1.7.5.hww02-20170911.072202-2-sources.jar: cn/com/duiba/activity/center/api/dto/activity_brick/PopupActivityBrickDto.java <==
package cn.com.duiba.activity.center.api.dto.activity_brick;

import java.io.Serializable;

/** 
 * ClassName:PopupActivityBrickDto.java <br/>
 * @author  gey 
 * @date 创建时间：2016年10月12日 下午2:44:02 
 * @version 1.0 
 * @parameter  
 * @since   JDK 1.6
 */
public class PopupActivityBrickDto implements Serializable {

	private static final long serialVersionUID = 774554467226696787L;
	
	public static final int STATUS_ON = 1; // 启用
    public static final int STATUS_OFF = 0; // 禁用
    
    public static final int TypeSign = 0; // 签到
    public static final int TypePlugin = 1; // 插件

	public static final int TYPE_CUSTOM_HDTOOL = 2; //自定义活动工具

	private Long id;
	//appId
	private Long appId;
	//皮肤名称
	private String name;
	//皮肤内容
	private String content;
	//md5
	private String md5;
	//排序
	private Integer position;
	//预览图
	private String image;
	//类型
	private Integer type;
	//状态（0：关闭，1：开启）
	private Integer status;
	
	private String appIdStr;
	
    public String getAppIdStr() {
        return appIdStr;
    }
    
    public void setAppIdStr(String appIdStr) {
        this.appIdStr = appIdStr;
    }
    public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getAppId() {
		return appId;
	}
	public void setAppId(Long appId) {
		this.appId = appId;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getContent() {
		return content;
	}
	public void setContent(String content) {
		this.content = content;
	}
	public String getMd5() {
		return md5;
	}
	public void setMd5(String md5) {
		this.md5 = md5;
	}
	public Integer getPosition() {
		return position;
	}
	public void setPosition(Integer position) {
		this.position = position;
	}
	public String getImage() {
		return image;
	}
	public void setImage(String image) {
		this.image = image;
	}
	public Integer getType() {
		return type;
	}
	public void setType(Integer type) {
		this.type = type;
	}
	public Integer getStatus() {
		return status;
	}
	public void setStatus(Integer status) {
		this.status = status;
	}
}

==> activity-center-api-2.2.4.hww02-20180115.062432-1-sources.jar: cn/com/duiba/activity/center/api/dto/activity_brick/PopupActivityBrickDto.java <==
package cn.com.duiba.activity.center.api.dto.activity_brick;

import java.io.Serializable;

/** 
 * ClassName:PopupActivityBrickDto.java <br/>
 * @author  gey 
 * @date 创建时间：2016年10月12日 下午2:44:02 
 * @version 1.0 
 * @parameter  
 * @since   JDK 1.6
 */
public class PopupActivityBrickDto implements Serializable {

	private static final long serialVersionUID = 774554467226696787L;
	
	public static final int STATUS_ON = 1; // 启用
    public static final int STATUS_OFF = 0; // 禁用
    
    public static final int TypeSign = 0; // 签到
    public static final int TypePlugin = 1; // 插件活动

	public static final int TYPE_CUSTOM_HDTOOL = 2; //自定义活动工具
	public static final int TYPE_THROUGH_HDTOOL = 3; //闯关游戏皮肤

	public static final int TYPE_PLUGIN_TOOL = 4; // 插件式抽奖工具

	private Long id;
	//appId
	private Long appId;
	//皮肤名称
	private String name;
	//皮肤内容
	private String content;
	//md5
	private String md5;
	//排序
	private Integer position;
	//预览图
	private String image;
	//类型
	private Integer type;
	//状态（0：关闭，1：开启）
	private Integer status;
	
	private String appIdStr;
	
    public String getAppIdStr() {
        return appIdStr;
    }
    
    public void setAppIdStr(String appIdStr) {
        this.appIdStr = appIdStr;
    }
    public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getAppId() {
		return appId;
	}
	public void setAppId(Long appId) {
		this.appId = appId;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getContent() {
		return content;
	}
	public void setContent(String content) {
		this.content = content;
	}
	public String getMd5() {
		return md5;
	}
	public void setMd5(String md5) {
		this.md5 = md5;
	}
	public Integer getPosition() {
		return position;
	}
	public void setPosition(Integer position) {
		this.position = position;
	}
	public String getImage() {
		return image;
	}
	public void setImage(String image) {
		this.image = image;
	}
	public Integer getType() {
		return type;
	}
	public void setType(Integer type) {
		this.type = type;
	}
	public Integer getStatus() {
		return status;
	}
	public void setStatus(Integer status) {
		this.status = status;
	}
}
